==> haskell-data-default-instances-containers-0.1.0.3-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-containers
version:              0.1.0.3
visibility:           public
id:
    data-default-instances-containers-0.1.0.3-9AZa3k8GyIQ5Jra3Lt11HS

key:
    data-default-instances-containers-0.1.0.3-9AZa3k8GyIQ5Jra3Lt11HS

license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in containers
description:
    This module defines '\''Default'\'' instances for the types '\''S.Set'\'', '\''M.Map'\'',
    '\''IntMap'\'', '\''IntSet'\'', '\''Seq'\'', and '\''Tree'\''.

category:             Data
abi:                  0bafdc00779f46e9b9c6c1b19cdd27ba
exposed:              True
exposed-modules:      Data.Default.Instances.Containers
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-containers-0.1.0.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-containers-0.1.0.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-containers-0.1.0.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-containers
hs-libraries:
    HSdata-default-instances-containers-0.1.0.3-9AZa3k8GyIQ5Jra3Lt11HS

depends:
    base-4.17.2.1 containers-0.6.7
    data-default-class-0.1.2.1-J2UCuIureY5CbnU1SgrtGb

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-containers/html/data-default-instances-containers.haddock

haddock-html:
    /usr/share/doc/haskell-data-default-instances-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-instances-containers-0.1.0.3-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-containers
version:              0.1.0.3
visibility:           public
id:
    data-default-instances-containers-0.1.0.3-HJEUx1mf2AUKWalj8lkrl1

key:
    data-default-instances-containers-0.1.0.3-HJEUx1mf2AUKWalj8lkrl1

license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in containers
description:
    This module defines '\''Default'\'' instances for the types '\''S.Set'\'', '\''M.Map'\'',
    '\''IntMap'\'', '\''IntSet'\'', '\''Seq'\'', and '\''Tree'\''.

category:             Data
abi:                  991a83822209106fe2204d6464417e14
exposed:              True
exposed-modules:      Data.Default.Instances.Containers
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-containers-0.1.0.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-containers-0.1.0.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-containers-0.1.0.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-containers
hs-libraries:
    HSdata-default-instances-containers-0.1.0.3-HJEUx1mf2AUKWalj8lkrl1

depends:
    base-4.17.2.1 containers-0.6.7
    data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-containers/html/data-default-instances-containers.haddock

haddock-html:
    /usr/share/doc/haskell-data-default-instances-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
